pub struct Array(/* private fields */);Expand description
An array of values
Implementations
Sourceimpl Array
impl Array
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates a new array with the given capacity
Sourcepub fn get(&self, index: usize) -> Option<&Value>
pub fn get(&self, index: usize) -> Option<&Value>
Returns a reference to the element at the given index
Sourcepub fn get_mut(&mut self, index: usize) -> Option<&mut Value>
pub fn get_mut(&mut self, index: usize) -> Option<&mut Value>
Returns a mutable reference to the element at the given index
Sourcepub fn iter_mut(&mut self) -> IterMut<'_, Value>
pub fn iter_mut(&mut self) -> IterMut<'_, Value>
Returns an iterator that allows modifying each value